/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.core;

import java.io.File;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;

import blanco.tmx.BlancoTmxParser;
import blanco.tmx.BlancoTmxSerializer;
import blanco.tmx.valueobject.BlancoTmx;
import blanco.tmx.valueobject.BlancoTmxTu;

/**
 * TMX モデルとファイルを紐付けて保持するクラスです。
 */
public class Tmx {

	public static Tmx loadInstance(File file) {
		return new Tmx(file, new BlancoTmxParser().parse(file));
	}

	public static Tmx newInstance(File file) {
		return new Tmx(file, new BlancoTmx());
	}

	private final File file;
	private final BlancoTmx blancoTmx;

	private Tmx(File file, BlancoTmx blancoTmx) {
		this.file = file;
		this.blancoTmx = blancoTmx;
	}

	public List<BlancoTmxTu> getTuList() {
		return blancoTmx.getBody().getTuList();
	}

	public BlancoTmxTu createBlancoTmxTu() {
		BlancoTmxTu tu = new BlancoTmxTu();
		getTuList().add(tu);
		return tu;
	}

	public void save() throws IOException {
		List<BlancoTmxTu> newFileList = new LinkedList<BlancoTmxTu>();
		for (BlancoTmxTu tu : getTuList()) {
			if (tu.getTuvList().size() > 0) {
				newFileList.add(tu);
			}
		}
		if (newFileList.size() > 0) {
			blancoTmx.getBody().setTuList(newFileList);
			new BlancoTmxSerializer().serialize(blancoTmx, file);
		}
	}
}
