/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.core.dom;

import java.util.LinkedList;
import java.util.List;

import org.eclipse.wst.xml.core.internal.provisional.document.IDOMDocument;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * XLIFF の trans-unit 要素です。
 */
@SuppressWarnings("restriction")
public class TransUnitDelegate extends TransBaseDelegate {

	private final IDOMDocument domDocument;

	public TransUnitDelegate(IDOMDocument domDocument, Element element) {
		super(element);
		this.domDocument = domDocument;
	}

	public String getId() {
		return getValue("@id");
	}

	public void setContextGroupTmOmit(boolean omit) {
		NodeList contextGroups = element.getElementsByTagName("context-group");
		if (contextGroups.getLength() > 0) {
			Node contextGroup = contextGroups.item(0);
			element.removeChild(contextGroup.getNextSibling());
			element.removeChild(contextGroup);
		}
		if (omit) {
			Element contextGroup = domDocument.createElement("context-group");
			contextGroup.setAttribute("purpose", "x-tm");
			Element context = domDocument.createElement("context");
			context.setAttribute("context-type", "x-omit");

			contextGroup.appendChild(domDocument.createTextNode("\n          "));
			contextGroup.appendChild(context);
			contextGroup.appendChild(domDocument.createTextNode("\n        "));

			insertAfter(contextGroup, getChildElement("target"), getChildElement("source"));
		}
	}

	public boolean isContextGourpTmOmit() {
		return "x-omit".equals(getValue("context-group/context/@context-type"));
	}

	public boolean setTranslate(boolean translate) {
		String newTranslate = translate ? "yes" : "no";
		String oldTranslate = getValue("@translate", "yes");
		if (!oldTranslate.equals(newTranslate)) {
			setValue("@translate", newTranslate);
			return true;
		}
		return false;
	}

	public boolean isTranslate() {
		return "yes".equals(getValue("@translate", "yes"));
	}

	public boolean setTarget(String target) {
		String old = getValue("target", null);
		if (old == null && (target == null || target.equals(""))) {
			return false;
		}
		if (!target.equals(old)) {
			if (getChildElement("target") == null) {
				Element targetElement = domDocument.createElement("target");
				org.w3c.dom.Text textNode = domDocument.createTextNode("");
				targetElement.appendChild(textNode);
				insertAfter(targetElement, getChildElement("source"));
			}
			setValue("target", target);
			return true;
		}
		return false;
	}

	public boolean setTargetState(String state) {
		String oldState = getTargetState();
		if (!state.equals(oldState)) {
			if (getChildElement("target") == null) {
				setTarget("");
			}
			setValue("target/@state", state);
			return true;
		}
		return false;
	}

	public String getTargetState() {
		return getValue("target/@state");
	}

	public Node appendNote(String from, String text) {
		Element noteElement = domDocument.createElement("note");
		org.w3c.dom.Text textNode = domDocument.createTextNode(text);
		noteElement.appendChild(textNode);
		noteElement.setAttribute("from", from);
		NodeList noteList = element.getElementsByTagName("note");
		Node lastNote = noteList.item(noteList.getLength() - 1);
		insertAfter(noteElement, lastNote);
		return noteElement;
	}

	public void removeNote(ElementDelegate note) {
		element.removeChild(note.getElement().getNextSibling());
		element.removeChild(note.getElement());
	}

	private void insertAfter(Node insertNode, Node... beforeNodes) {
		for (Node beforeNode : beforeNodes) {
			if (beforeNode != null) {
				Node afterTarget = beforeNode.getNextSibling().getNextSibling();
				element.insertBefore(insertNode, afterTarget);
				element.insertBefore(domDocument.createTextNode("\n        "), afterTarget);
				break;
			}
		}
	}

	public List<AltTransDelegate> getAltTransList() {
		return getList(AltTransDelegate.class, "alt-trans");
	}

	public List<NoteDelegate> getNoteList() {
		return getList(NoteDelegate.class, "note");
	}

	public static List<TransUnitDelegate> listOf(IDOMDocument domDocument) {
		NodeList nodeList = domDocument.getElementsByTagName("trans-unit");
		List<TransUnitDelegate> list = new LinkedList<TransUnitDelegate>();
		for (int i = 0; i < nodeList.getLength(); i++) {
			TransUnitDelegate ele = new TransUnitDelegate(domDocument, (Element) nodeList.item(i));
			list.add(ele);
		}
		return list;
	}
}
